@@ -18,7 +18,7 @@ Apart of algorithm specific parameters, all of them feature the same basic param
 
 - [`markov`][ragraph.analysis.cluster.markov]
 - [`hierarchical_markov`][ragraph.analysis.cluster.hierarchical_markov]
-- ['tarjans_scc`][ragraph.analysis.cluster.tarjans_scc]
+- [`tarjans_scc`][ragraph.analysis.cluster.tarjans_scc]
 """
 
 from ragraph.analysis.cluster._markov import (
