@@ -2,15 +2,23 @@
 
 import enum
 from copy import deepcopy
-from typing import Iterable
+from typing import TYPE_CHECKING, Iterable
 
 from ragraph.edge import Edge
 from ragraph.generic import Metadata
 from ragraph.graph import Graph
 from ragraph.node import Node
 
+try:
+    StrEnum = enum.StrEnum
+except Exception:
+    from strenum import StrEnum  # type: ignore
+finally:
+    if TYPE_CHECKING:
+        StrEnum = enum.StrEnum
 
-class SigmaMode(enum.StrEnum):
+
+class SigmaMode(StrEnum):
     """Aggregation mode for sigma analysis, absolute counted occurrences or an average per graph."""
 
     ABSOLUTE = enum.auto()
