@@ -1,14 +1,23 @@
 """# Comparison analysis utilities"""
+
 import enum
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-from typing import FrozenSet, Tuple
+from typing import TYPE_CHECKING, FrozenSet, Tuple
 
 from ragraph.edge import Edge
 from ragraph.generic import Metadata
 from ragraph.graph import Graph
 from ragraph.node import Node
 
+try:
+    StrEnum = enum.StrEnum
+except Exception:
+    from strenum import StrEnum  # type: ignore
+finally:
+    if TYPE_CHECKING:
+        StrEnum = enum.StrEnum
+
 
 class NodeDescriptorLike(ABC):
     """A class that takes a node and describes it by returning a fixed (hashable) output.
@@ -107,7 +116,7 @@ class EdgeDescriptor(EdgeDescriptorLike):
         return edge
 
 
-class TagMode(enum.StrEnum):
+class TagMode(StrEnum):
     """How to tag nodes as unique to one of the given inputs or common."""
 
     KIND = enum.auto()
