@@ -1,4 +1,7 @@
-"""Compatibility analysis between different variants for several functional elements."""
+"""# Compatibility analysis
+
+Calculate compatibility between different variants for several functional elements.
+"""
 
 from copy import deepcopy
 from itertools import combinations
@@ -7,6 +10,7 @@ from pathlib import Path
 from typing import Callable, Dict, Generator, Iterable, List, Optional, Tuple, Union
 
 from plotly import graph_objs as go
+
 from ragraph.analysis.compatibility.bdd import yield_feasible_configurations
 from ragraph.edge import Edge
 from ragraph.graph import Graph
@@ -42,17 +46,13 @@ def get_variant_score(
     Returns:
         Variant score.
     """
-    values = (
-        [variant.weights[k] for k in weights] if weights else variant.weights.values()
-    )
+    values = [variant.weights[k] for k in weights] if weights else variant.weights.values()
     if aggregation == "sum":
         return sum(values)
     return prod(values)
 
 
-def get_configuration_score(
-    variant_scores: Iterable[float], aggregation: str = "sum"
-) -> float:
+def get_configuration_score(variant_scores: Iterable[float], aggregation: str = "sum") -> float:
     """Score a configuration by aggregating variant scores by either taking the
     sum or product.
 
@@ -116,9 +116,7 @@ def get_compatibility_method(
         incompatible = (
             False
             if incompatibility_kind is None
-            else any(
-                e.kind == incompatibility_kind for e in graph[var1.name, var2.name]
-            )
+            else any(e.kind == incompatibility_kind for e in graph[var1.name, var2.name])
             or any(e.kind == incompatibility_kind for e in graph[var2.name, var1.name])
         )
         return not incompatible
@@ -151,28 +149,16 @@ def get_applicability_method(
         applicable = (
             True
             if applicability_kind is None
-            else any(
-                e.kind == applicability_kind
-                for e in graph[element.name, constraint.name]
-            )
-            or any(
-                e.kind == applicability_kind
-                for e in graph[constraint.name, element.name]
-            )
+            else any(e.kind == applicability_kind for e in graph[element.name, constraint.name])
+            or any(e.kind == applicability_kind for e in graph[constraint.name, element.name])
         )
         if not applicable:
             return False
         inapplicable = (
             False
             if inapplicability_kind is None
-            else any(
-                e.kind == inapplicability_kind
-                for e in graph[element.name, constraint.name]
-            )
-            or any(
-                e.kind == inapplicability_kind
-                for e in graph[constraint.name, element.name]
-            )
+            else any(e.kind == inapplicability_kind for e in graph[element.name, constraint.name])
+            or any(e.kind == inapplicability_kind for e in graph[constraint.name, element.name])
         )
         return not inapplicable
 
@@ -224,7 +210,8 @@ class CompatibilityAnalysis:
         interface_compatibility: When set, the compatibility of two variants is only
             checked when they share an interface.
         score_method: A method accepting a tuple of variant nodes and
-            returning a single performance score. See :obj:`get_score_method`.
+            returning a single performance score. See
+            [`get_score_method`][ragraph.analysis.compatibility.get_score_method].
         constraints: Optional list of constraint nodes ("project scope") for which
             variants must be applicable in order to be taken into account.
         applicability_method: A method accepting a graph, a variant node and a
@@ -252,10 +239,8 @@ class CompatibilityAnalysis:
         self,
         graph: Graph,
         variants: Dict[str, List[Node]],
-        interface_method: Callable[[Graph, Node, Node], bool] = None,
-        compatibility_method: Callable[
-            [Graph, Node, Node], bool
-        ] = get_compatibility_method(
+        interface_method: Optional[Callable[[Graph, Node, Node], bool]] = None,
+        compatibility_method: Callable[[Graph, Node, Node], bool] = get_compatibility_method(
             compatibility_kind="compatibility", incompatibility_kind=None
         ),
         interface_compatibility: bool = True,
@@ -263,18 +248,33 @@ class CompatibilityAnalysis:
             variant_agg="sum", config_agg="sum", weights=None
         ),
         constraints: Optional[List[Node]] = None,
-        applicability_method: Callable[
-            [Graph, Node, Node], bool
-        ] = get_applicability_method(
+        applicability_method: Callable[[Graph, Node, Node], bool] = get_applicability_method(
             applicability_kind="applicability", inapplicability_kind=None
         ),
     ):
         self.graph = graph
+        """Graph containing compatibility data between different variants."""
+
         self.interface_method = interface_method
+        """An optional method accepting a Graph and two variant nodes that returns whether the two
+        given variants have an interface. Acts as a guard for whether compatibility checking is
+        necessary when `interface_compatibility` is set."""
+
         self.compatibility_method = compatibility_method
+        """A method accepting a Graph and two variant nodes to check whether the two given variants
+        are compatible (by returning `True`)."""
+
         self.interface_compatibility = interface_compatibility
+        """When set, the compatibility of two variants is only checked when they share an interface.
+        """
+
         self.applicability_method = applicability_method
+        """A method accepting a graph, a variant node and a constraint node that returns whether a
+        variant is applicable when that constraint is set."""
+
         self.score_method = score_method
+        """A method accepting a tuple of variant nodes and returning a single performance score.
+        See [`get_score_method`][ragraph.analysis.compatibility.get_score_method]."""
 
         self._elements: List[str] = []
         self._element_nums: List[int] = []
@@ -320,14 +320,14 @@ class CompatibilityAnalysis:
     @property
     def elements(self) -> List[str]:
         """Enabled elements with at least one applicable variant.
-        See :obj:`self.constraints` and :obj:`self.applicability_method`
+        See `self.constraints` and `self.applicability_method`.
         """
         return self._elements
 
     @property
     def disabled_elements(self) -> List[str]:
         """Disabled elements with no applicable variant.
-        See :obj:`self.constraints` and :obj:`self.applicability_method`
+        See `self.constraints` and `self.applicability_method`.
         """
         return self._disabled_elements
 
@@ -343,22 +343,20 @@ class CompatibilityAnalysis:
 
     def is_applicable(self, variant: Node) -> bool:
         """Whether a variant is applicable to the currently set of constraints."""
-        if not self.constraints or not self.applicability_method:
-            return True
-        return all(
-            self.applicability_method(self.graph, variant, constraint)
-            for constraint in self.constraints
-        )
+        if self.constraints:
+            return all(
+                self.applicability_method(self.graph, variant, constraint)
+                for constraint in self.constraints
+            )
+        return True
 
     def has_interface(self, var1: Node, var2: Node) -> bool:
         """Whether two variants have an interface that needs a compatibility check."""
-        return (self.interface_method is None) or self.interface_method(
-            self.graph, var1, var2
-        )
+        return (self.interface_method is None) or self.interface_method(self.graph, var1, var2)
 
     def is_compatible(self, var1: Node, var2: Node) -> bool:
         """Whether the two given variants are compatible according to
-        :obj:`self.compatibility_method`
+        [`self.applicability_method`][ragraph.analysis.compatibility.CompatibilityAnalysis.applicability_method]
         """
 
         if self.interface_compatibility:
@@ -386,9 +384,7 @@ class CompatibilityAnalysis:
         variants = self._variants_list if variants is None else variants
         dim = len(variants)
         mat = (
-            np.zeros((dim, dim))
-            if HAVE_NUMPY
-            else [[0.0 for j in range(dim)] for i in range(dim)]
+            np.zeros((dim, dim)) if HAVE_NUMPY else [[0.0 for j in range(dim)] for i in range(dim)]
         )
         for i in range(dim):
             var1 = variants[i]
@@ -435,13 +431,9 @@ class CompatibilityAnalysis:
         Returns:
             Sorted tuples of configurations and scores.
         """
-        return sorted(
-            self.yield_scored_configurations(), key=lambda x: x[-1], reverse=descending
-        )
+        return sorted(self.yield_scored_configurations(), key=lambda x: x[-1], reverse=descending)
 
-    def write_csv(
-        self, path: Union[str, Path], scored: bool = True, limit: int = -1
-    ) -> int:
+    def write_csv(self, path: Union[str, Path], scored: bool = True, limit: int = -1) -> int:
         """Write feasible configurations and optional scores to a CSV file."""
         path = Path(path)
         num = 0
@@ -504,9 +496,7 @@ class CompatibilityAnalysis:
                         if self.has_interface(var1, var2):
                             e1.labels.append("interface")
                             e1.labels.append(
-                                "compatible"
-                                if self.is_compatible(var1, var2)
-                                else "incompatible"
+                                "compatible" if self.is_compatible(var1, var2) else "incompatible"
                             )
                         else:
                             e1.labels.append("no interface")
