@@ -1,4 +1,6 @@
-"""Graph describing a design problem using objects that need to be designed based on
+"""# Integral architecture example
+
+Graph describing a design problem using objects that need to be designed based on
 certain aspects. It is part of a set of three design problem graphs, each ideally solved
 with a different approach -- being a modular, **integral** or mixed architecture.
 
@@ -11,7 +13,8 @@ relatively few. A module's design solution should be applicable to every member.
 
 Nodes are of kind "object" or "aspect_1", "aspect_2", and "aspect_3". The numbers
 represent different aspect domains. An "incidence" kind edge from an object to an aspect
-means that it posesses that aspect.
+means that it possesses that aspect.
 
-Authors: Tim Wilschut and Tiemen Schuijbroek, October 2019.
+Authors:
+    Tim Wilschut and Tiemen Schuijbroek, October 2019.
 """
