@@ -1,4 +1,4 @@
-"""LED system-in-package (LEDSiP) decomposed into 1200 components.
+"""# LED system-in-package (LEDSiP, 1200 components)
 
 Reference:
 Wilschut, T. (2014). Analysis of the multi-disciplinary coupling structure of a LED
