@@ -3,13 +3,49 @@
 Metadata includes the kinds, labels, weights and annotations that we assign to our data
 objects. Standardizing this enables a more predictable experience.
 """
+
+import enum
 import uuid as _uuid
 from collections import defaultdict
 from copy import deepcopy
-from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Set, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    Iterable,
+    List,
+    Optional,
+    Set,
+    Union,
+)
 from warnings import warn
 
 
+try:
+    StrEnum = enum.StrEnum
+except Exception:
+    from strenum import StrEnum  # type: ignore
+finally:
+    if TYPE_CHECKING:
+        StrEnum = enum.StrEnum
+
+
+class Convention(StrEnum):
+    """Convention for matrix conversion to follow. Either:
+
+    - Inputs in rows, feedback above diagonal (IR_FAD)
+    - Inputs in columns, feedback below diagonal (IC_FBD)
+    """
+
+    IR_FAD = enum.auto()
+    """Inputs in rows, feedback above diagonal."""
+
+    IC_FBD = enum.auto()
+    """Inputs in columns, feedback below diagonal."""
+
+
 class MappingValidationError(Exception):
     pass
 
