@@ -4,14 +4,27 @@ The [`Graph`][ragraph.graph.Graph] class is the core of this package. It is the
 format that facilitates all conversions. These class definitions are designed to
 accommodate a wide range of graph formats.
 """
+
 from collections import OrderedDict, defaultdict
 from copy import deepcopy
-from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Set, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generator,
+    Iterable,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    Union,
+)
 from uuid import UUID
 
 from ragraph import utils
 from ragraph.edge import Edge
 from ragraph.generic import Annotations, Metadata
+from ragraph.generic import Convention
 from ragraph.node import Node
 
 try:
@@ -642,6 +655,7 @@ class Graph(Metadata):
         inherit: bool = False,
         loops: bool = False,
         only: Optional[List[str]] = None,
+        convention: Convention = Convention.IR_FAD,
     ) -> Union["np.ndarray", List[List[float]]]:
         """Convert graph data into a numerical adjacency matrix.
 
@@ -658,7 +672,15 @@ class Graph(Metadata):
         """
         from ragraph.io.matrix import to_matrix
 
-        return to_matrix(self, rows=nodes, cols=nodes, inherit=inherit, loops=loops, only=only)
+        return to_matrix(
+            self,
+            rows=nodes,
+            cols=nodes,
+            inherit=inherit,
+            loops=loops,
+            only=only,
+            convention=convention,
+        )
 
     def get_mapping_matrix(
         self,
@@ -667,6 +689,7 @@ class Graph(Metadata):
         inherit: bool = False,
         loops: bool = False,
         only: Optional[List[str]] = None,
+        convention: Convention = Convention.IR_FAD,
     ) -> Union["np.ndarray", List[List[float]]]:
         """Convert graph data into a numerical mapping matrix.
 
@@ -684,7 +707,15 @@ class Graph(Metadata):
         """
         from ragraph.io.matrix import to_matrix
 
-        return to_matrix(self, rows=rows, cols=cols, inherit=inherit, loops=loops, only=only)
+        return to_matrix(
+            self,
+            rows=rows,
+            cols=cols,
+            inherit=inherit,
+            loops=loops,
+            only=only,
+            convention=convention,
+        )
 
     def get_ascii_art(
         self,
@@ -692,6 +723,7 @@ class Graph(Metadata):
         edge: str = "X",
         diag: str = "\u25A0",
         show: bool = False,
+        convention: Convention = Convention.IR_FAD,
     ) -> Optional[str]:
         """Get a unicode ASCII art representation of a binary adjacency matrix for a
         given set of nodes.
@@ -724,15 +756,24 @@ class Graph(Metadata):
 
         lines = [topline]
 
-        for i, tgt in enumerate(nodes):
-            line = (maxlen - namelens[i]) * " " + tgt.name + "\u2525"
-            for j, src in enumerate(nodes):
+        for i, row in enumerate(nodes):
+            line = (maxlen - namelens[i]) * " " + row.name + "\u2525"
+            for j, col in enumerate(nodes):
                 if i == j:
                     mark = diag
-                elif self._directed_edges.get(src.name, dict()).get(tgt.name, False):
-                    mark = edge
                 else:
-                    mark = " "
+                    if convention == Convention.IR_FAD:
+                        src = col
+                        tgt = row
+                    elif convention == Convention.IC_FBD:
+                        src = row
+                        tgt = col
+                    else:
+                        raise ValueError("Unknown matrix convention type.")
+                    if self._directed_edges.get(src.name, dict()).get(tgt.name, False):
+                        mark = edge
+                    else:
+                        mark = " "
                 line += " {} \u2502".format(mark)
 
             lines.append(line)
