@@ -54,7 +54,7 @@ def from_canopy(
 def to_canopy(
     graph: Graph,
     path: Optional[Union[Path, str]] = None,
-    fmt: str = "session",
+    fmt: str = "graph",
 ) -> Optional[str]:
     """Save graph as a Canopy dataset.
 
