@@ -78,7 +78,7 @@ def from_csv(
 
 def to_csv(
     graph: Graph,
-    stem_path: str,
+    stem_path: Union[str, Path],
     csv_delimiter: str = ";",
     iter_delimiter: str = ";",
     use_uuid: bool = False,
@@ -140,7 +140,11 @@ def _load_nodes(
     for row in rows:
         name = row["name"]
         anno = Annotations(**{col: row[col] for col in anno_cols})
-        weights = {col: _convert_to_num(row[col]) for col in wght_cols}
+        weights = {
+            col: _convert_to_num(row[col])
+            for col in wght_cols
+            if row[col] != "" and row[col] is not None
+        }
         names.append(name)
         uuid = row.get("uuid", None)
         nodes.append(Node(name, weights=weights, annotations=anno, uuid=uuid))
@@ -179,7 +183,7 @@ def _load_nodes(
     return node_dict
 
 
-def _derive_nodes(edges_path: Union[str, Path], csv_delimiter: str) -> Dict[str, Node]:
+def _derive_nodes(edges_path: Optional[Union[str, Path]], csv_delimiter: str) -> Dict[str, Node]:
     """Derive nodes from edges CSV file.
 
     Arguments:
@@ -189,10 +193,12 @@ def _derive_nodes(edges_path: Union[str, Path], csv_delimiter: str) -> Dict[str,
     Returns:
         Node dictionary (name, node).
     """
+    if not edges_path:
+        return OrderedDict()
 
     with Path(edges_path).open(newline="") as f:
         reader = csv.DictReader(f, delimiter=csv_delimiter)
-        columns = reader.fieldnames
+        columns = reader.fieldnames or []
         rows = [row for row in reader]
     if "source" not in columns or "target" not in columns:
         raise ValueError(
@@ -252,7 +258,11 @@ def _load_edges(
     for row in rows:
         if row.get("labels", None):
             row["labels"] = [s.strip() for s in row["labels"].split(iter_delimiter)]
-        weights = {col: _convert_to_num(row[col]) for col in wght_cols}
+        weights = {
+            col: _convert_to_num(row[col])
+            for col in wght_cols
+            if row[col] != "" and row[col] is not None
+        }
         anno = Annotations(**{col: row[col] for col in anno_cols})
         kwargs = {col: row[col] for col in columns if col in EDGE_COLUMNS}
         kwargs["source"] = node_dict[kwargs["source"]]
@@ -392,7 +402,7 @@ def _save_edges(
                 row_dict["uuid"] = str(edge.uuid)
 
             for key, value in wght_map.items():
-                row_dict[value] = edge.weights[key]
+                row_dict[value] = edge.weights.get(key, None)
 
             for key, value in anno_map.items():
                 row_dict[value] = getattr(edge.annotations, key, None)
