@@ -5,10 +5,10 @@ from typing import Any, Dict, List, Optional, Union
 from ragraph.edge import Edge
 from ragraph.graph import Graph
 from ragraph.node import Node
+from ragraph.generic import Convention
 
 try:
     import numpy as np
-
 except ImportError:
     np = None
 
@@ -19,6 +19,7 @@ def from_matrix(
     cols: Optional[Union[List[Node], List[str]]] = None,
     weight_label: str = "default",
     empty: Optional[Union[int, float]] = 0.0,
+    convention: Convention = Convention.IR_FAD,
     **graph_args: Dict[str, Any],
 ) -> Graph:
     """Create a graph from an adjacency or mapping matrix.
@@ -44,7 +45,7 @@ def from_matrix(
     rows = [Node(f"node{i}") for i in range(len(matrix))] if rows is None else rows
 
     # init empty graph
-    graph = Graph(**graph_args)
+    graph = Graph(**graph_args)  # type: ignore
 
     # Parse row labels and create new nodes.
     node_rows = _parse_labels(graph, rows)
@@ -62,17 +63,33 @@ def from_matrix(
         raise ValueError(f"Matrix dimensions {dim} do not agree with label dimensions {labdim}.")
 
     # Generate edges and return.
-    edges = [
-        Edge(
-            source,
-            target,
-            name=f"{source.name}->{target.name}",
-            weights={weight_label: matrix[row][col]},
-        )
-        for row, target in enumerate(node_rows)
-        for col, source in enumerate(node_cols)
-        if matrix[row][col] != empty
-    ]
+    if convention == Convention.IR_FAD:
+        edges = [
+            Edge(
+                source,
+                target,
+                name=f"{source.name}->{target.name}",
+                weights={weight_label: matrix[row][col]},
+            )
+            for row, target in enumerate(node_rows)
+            for col, source in enumerate(node_cols)
+            if matrix[row][col] != empty
+        ]
+    elif convention == Convention.IC_FBD:
+        edges = [
+            Edge(
+                source,
+                target,
+                name=f"{source.name}->{target.name}",
+                weights={weight_label: matrix[row][col]},
+            )
+            for row, source in enumerate(node_rows)
+            for col, target in enumerate(node_cols)
+            if matrix[row][col] != empty
+        ]
+    else:
+        raise ValueError("Unknown convention for matrix conversion.")
+
     graph.edges = edges
     return graph
 
@@ -84,7 +101,8 @@ def to_matrix(
     inherit: bool = False,
     loops: bool = False,
     only: Optional[List[str]] = None,
-) -> Union[np.ndarray, List[List[float]]]:
+    convention: Convention = Convention.IR_FAD,
+) -> Union["np.ndarray", List[List[float]]]:
     """Convert graph data into a directed numerical adjacency or mapping matrix.
 
     Arguments:
@@ -119,13 +137,23 @@ def to_matrix(
     else:
         matrix = [[0.0 for j in range(dim[1])] for i in range(dim[0])]
 
-    for col, source in enumerate(cols):
-        for row, target in enumerate(rows):
-            if source == target and not loops:
+    for col, col_node in enumerate(cols):
+        for row, row_node in enumerate(rows):
+            if col_node == row_node and not loops:
                 continue
 
+            if convention == Convention.IR_FAD:
+                source = col_node
+                target = row_node
+            elif convention == Convention.IC_FBD:
+                source = row_node
+                target = col_node
+            else:
+                raise ValueError("Unknown convention for matrix conversion.")
+
             sources = [source]
             targets = [target]
+
             if inherit:
                 sources.extend(source.descendants)
                 targets.extend(target.descendants)
