@@ -1,4 +1,5 @@
 """# RaGraph plotting module"""
+
 from typing import Any, Dict, Iterable, List, Optional
 
 from plotly import graph_objects as go
@@ -7,8 +8,9 @@ from ragraph.edge import Edge
 from ragraph.graph import Graph
 from ragraph.node import Node
 from ragraph.plot.generic import Style
+from ragraph.plot.components.chord import chord
 
-__all__ = ["Style", "dsm", "dmm", "mdm"]
+__all__ = ["Style", "dsm", "dmm", "mdm", "chord"]
 
 
 def dsm(
