@@ -1,16 +1,18 @@
+"""# Blank plot component"""
+
 import plotly.graph_objs as go
+
 from ragraph.plot.generic import Component, Style
 
 
 class Blank(Component):
-    """Blank plot component
+    """Blank plot component.
 
     Arguments:
         style: Plot style mapping.
     """
 
-    def __init__(self, style=Style()):
-
+    def __init__(self, style: Style = Style()):
         trace = go.Scatter(
             x=[0.5 * style.xstep],
             y=[0.5 * style.ystep],
