@@ -14,6 +14,7 @@ Furthermore, bus nodes have their respective row and column in a shaded backgrou
 color. This sets apart the buses' "highly integrative" edges from the regular edges
 between nodes.
 """
+
 from collections import OrderedDict, defaultdict
 from copy import deepcopy
 from math import cos, pi, prod, sin
@@ -23,6 +24,7 @@ import plotly.graph_objs as go
 
 from ragraph import colors
 from ragraph.edge import Edge
+from ragraph.generic import Convention
 from ragraph.node import Node
 from ragraph.plot import svg
 from ragraph.plot.generic import Component, Style
@@ -233,8 +235,22 @@ def _get_pies_data(rows: List[Node], cols: List[Node], edges: List[Edge], style:
     # Calculate actual traces and shapes.
     traces = []
     shapes = []
-    for i, source in enumerate(cols):
-        for j, target in enumerate(rows):
+    for i, col in enumerate(cols):
+        if style.convention == Convention.IR_FAD:
+            source = col
+        elif style.convention == Convention.IC_FBD:
+            target = col
+        else:
+            raise ValueError("Unknown matrix convention.")
+
+        for j, row in enumerate(rows):
+            if style.convention == Convention.IR_FAD:
+                target = row
+            elif style.convention == Convention.IC_FBD:
+                source = row
+            else:
+                raise ValueError("Unknown matrix convention.")
+
             bundle = bundle_dict[source.name, target.name]
             if not bundle:
                 continue  # No edges here.
@@ -289,8 +305,22 @@ def _get_bundle_dict(
 
     # Calculate edge bundles:
     bundle_dict: Dict[Tuple[str, str], List[Edge]] = defaultdict(list)
-    for i, source in enumerate(cols):
-        for j, target in enumerate(rows):
+    for col in cols:
+        if style.convention == Convention.IR_FAD:
+            source = col
+        elif style.convention == Convention.IC_FBD:
+            target = col
+        else:
+            raise ValueError("Unknown matrix convention.")
+
+        for row in rows:
+            if style.convention == Convention.IR_FAD:
+                target = row
+            elif style.convention == Convention.IC_FBD:
+                source = row
+            else:
+                raise ValueError("Unknown matrix convention.")
+
             bundle = edge_dict[source.name, target.name]
             bundle.extend(
                 e
