@@ -1,4 +1,5 @@
 """# RaGraph generic plotting classes"""
+
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
@@ -6,7 +7,7 @@ from plotly import graph_objs as go
 from plotly.basedatatypes import BaseTraceType
 
 from ragraph import colors
-from ragraph.generic import Mapping, field
+from ragraph.generic import Convention, Mapping, field
 from ragraph.plot import svg
 
 MODEBAR_BUTTONS = {
@@ -124,7 +125,7 @@ class LabelsStyle(Mapping):
 
     _defaults = dict(
         fontcolor="black",
-        fontfamily="Hack,Courier New,monospace",
+        fontfamily="Fira Code,Hack,Courier New,monospace",
         fontsize=None,
         fontaspectratio=0.6005,
         shorten=True,
@@ -577,7 +578,7 @@ class LegendStyle(Mapping):
 
     _defaults = dict(
         fontcolor="black",
-        fontfamily="Hack,Courier New,monospace",
+        fontfamily="Fira Code,Hack,Courier New,monospace",
         fontsize=None,
         fontaspectratio=0.6005,
         height=10,
@@ -653,8 +654,7 @@ class LegendStyle(Mapping):
 
     @field
     def height(self) -> int:  # type: ignore
-        """Height of the swatch plot in number of box sizes when plotting a
-        numerical legend."""
+        """Height of the swatch plot in number of box sizes when plotting a numerical legend."""
 
     @field
     def n_ticks(self) -> int:  # type: ignore
@@ -669,10 +669,115 @@ class LegendStyle(Mapping):
         """Plotly Y-axis settings."""
 
 
+class ChordStyle(Mapping):
+    """RaGraph chord style mapping.
+
+    Arguments:
+        radius: Radius of the Chord plot.
+        padding: Padding to apply around the Chord plot.
+        gap_size: Gap size between the nodes in the Chord plot.
+        ribbon_gap: Gap size between the outside arc (circle) and ribbons.
+        ribbon_stiffness: Tweaks the curvature of the ribbons (0.0 straight, 1.0 delayed curve).
+        arc_thickness: Thickness of the outside arc (circle).
+        bg_color: Background color of the Chord plot.
+        bg_transparency: Background color transparency of the Chord plot.
+        fontsize: Chord plot font size.
+        fontfactor: Font factor to calculate the padding with.
+        fontfamily: Chord plot font family.
+    """
+
+    _defaults = dict(
+        radius=200,
+        padding=None,
+        gap_size=0.008,
+        ribbon_gap=0.0,
+        ribbon_stiffness=0.6,
+        arc_thickness=0.05,
+        bg_color="#ffffff",
+        bg_transparency=0.0,
+        fontsize=10,
+        fontfactor=0.72,
+        fontfamily="Fira Code,Noto Sans,Courier New,monospace",
+    )
+
+    def __init__(
+        self,
+        radius: Optional[Union[int, float]] = None,
+        padding: Optional[Union[int, float]] = None,
+        gap_size: Optional[float] = None,
+        ribbon_gap: Optional[float] = None,
+        ribbon_stiffness: Optional[float] = None,
+        arc_thickness: Optional[float] = None,
+        bg_color: Optional[str] = None,
+        bg_transparency: Optional[float] = None,
+        fontsize: Optional[float] = None,
+        fontfactor: Optional[float] = None,
+        fontfamily: Optional[str] = None,
+    ):
+        super().__init__(
+            radius=radius,
+            padding=padding,
+            gap_size=gap_size,
+            ribbon_gap=ribbon_gap,
+            ribbon_stiffness=ribbon_stiffness,
+            arc_thickness=arc_thickness,
+            bg_color=bg_color,
+            bg_transparency=bg_transparency,
+            fontsize=fontsize,
+            fontfactor=fontfactor,
+            fontfamily=fontfamily,
+        )
+
+    @field
+    def radius(self) -> Union[int, float]:  # type: ignore
+        """Radius of the Chord plot."""
+
+    @field
+    def padding(self) -> Union[int, float]:  # type: ignore
+        """Padding to apply around the Chord plot."""
+
+    @field
+    def gap_size(self) -> float:  # type: ignore
+        """Gap size between the nodes in the Chord plot."""
+
+    @field
+    def ribbon_gap(self) -> float:  # type: ignore
+        """Gap size between the outside arc (circle) and ribbons."""
+
+    @field
+    def ribbon_stiffness(self) -> float:  # type: ignore
+        """Tweaks the curvature of the ribbons (0.0 straight, 1.0 delayed curve)."""
+
+    @field
+    def arc_thickness(self) -> float:  # type: ignore
+        """Thickness of the outside arc (circle)."""
+
+    @field
+    def bg_color(self) -> str:  # type: ignore
+        """Background color of the Chord plot."""
+
+    @field
+    def bg_transparency(self) -> float:  # type: ignore
+        """Background color transparency of the Chord plot."""
+
+    @field
+    def fontsize(self) -> Union[int, float]:  # type: ignore
+        """Chord plot font size."""
+
+    @field
+    def fontfactor(self) -> float:  # type: ignore
+        """Font factor to calculate the padding with."""
+
+    @field
+    def fontfamily(self) -> str:  # type: ignore
+        """Chord plot font family."""
+
+
 class Style(Mapping):
     """RaGraph plot style mapping.
 
     Arguments:
+        convention: Convention to use when drawing edges.
         boxsize: Size in pixels per row or column.
         config: Plotly Figure.show() config.
         highlight_annotation: Annotation key of instances that should be highlighted.
@@ -685,12 +790,14 @@ class Style(Mapping):
         tree: Tree plot style.
         legend: Legend plot style.
         show_legend: Bool to display legend.
+        chord: Chord plot style.
         row_col_numbers: Bool to display row and column numbers.
         xstep: Axis increment per row or column in plots (usually 1).
         ystep: Axis increment per row or column in plots (usually 1).
     """
 
     _defaults = dict(
+        convention=Convention.IR_FAD,
         boxsize=20,
         config=dict(
             displaylogo=False,
@@ -716,6 +823,7 @@ class Style(Mapping):
         tree=TreeStyle(),
         legend=LegendStyle(),
         show_legend=True,
+        chord=ChordStyle(),
         row_col_numbers=True,
         xstep=1,
         ystep=1,
@@ -723,6 +831,7 @@ class Style(Mapping):
 
     def __init__(
         self,
+        convention: Optional[Convention] = None,
         boxsize: Optional[int] = None,
         config: Optional[Dict[str, Any]] = None,
         highlight_annotation: Optional[str] = None,
@@ -734,11 +843,13 @@ class Style(Mapping):
         tree: Optional[Union[TreeStyle, Dict[str, Any]]] = None,
         legend: Optional[Union[LegendStyle, Dict[str, Any]]] = None,
         show_legend: Optional[bool] = None,
+        chord: Optional[Union[ChordStyle, Dict[str, Any]]] = None,
         row_col_numbers: Optional[bool] = None,
         xstep: Optional[str] = None,
         ystep: Optional[str] = None,
     ):
         super().__init__(
+            convention=convention,
             boxsize=boxsize,
             config=config,
             highlight_annotation=highlight_annotation,
@@ -750,11 +861,16 @@ class Style(Mapping):
             tree=tree,
             legend=legend,
             show_legend=show_legend,
+            chord=chord,
             row_col_numbers=row_col_numbers,
             xstep=xstep,
             ystep=ystep,
         )
 
+    @field
+    def convention(self) -> Convention:  # type: ignore
+        """Convention to use when drawing edges."""
+
     @field
     def boxsize(self) -> int:  # type: ignore
         """Size in pixels per row or column."""
@@ -800,6 +916,10 @@ class Style(Mapping):
     def show_legend(self) -> bool:  # type: ignore
         """Boolean to display a legend."""
 
+    @field
+    def chord(self) -> ChordStyle:  # type: ignore
+        """Chord plot style."""
+
     @field
     def row_col_numbers(self) -> bool:  # type: ignore
         """Boolean to display row and column numbers."""
